@@ -16,7 +16,6 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """This module contains a object that represents a Telegram Audio."""
 
 from telegram import TelegramObject
@@ -45,10 +44,7 @@ class Audio(TelegramObject):
         file_size (Optional[int]):
     """
 
-    def __init__(self,
-                 file_id,
-                 duration,
-                 **kwargs):
+    def __init__(self, file_id, duration, **kwargs):
         # Required
         self.file_id = str(file_id)
         self.duration = int(duration)
@@ -59,10 +55,11 @@ class Audio(TelegramObject):
         self.file_size = int(kwargs.get('file_size', 0))
 
     @staticmethod
-    def de_json(data):
+    def de_json(data, bot):
         """
         Args:
-            data (str):
+            data (dict):
+            bot (telegram.Bot):
 
         Returns:
             telegram.Audio:
