@@ -25,7 +25,7 @@ from telegram import TelegramObject, Message, User
 class CallbackQuery(TelegramObject):
     """This object represents a Telegram CallbackQuery."""
 
-    def __init__(self, id, from_user, data, **kwargs):
+    def __init__(self, id, from_user, data, bot=None, **kwargs):
         # Required
         self.id = id
         self.from_user = from_user
@@ -34,15 +34,26 @@ class CallbackQuery(TelegramObject):
         self.message = kwargs.get('message')
         self.inline_message_id = kwargs.get('inline_message_id', '')
 
+        self.bot = bot
+
     @staticmethod
-    def de_json(data):
+    def de_json(data, bot):
+        """
+        Args:
+            data (dict):
+            bot (telegram.Bot):
+
+        Returns:
+            telegram.CallbackQuery:
+        """
+
         if not data:
             return None
 
-        data['from_user'] = User.de_json(data.get('from'))
-        data['message'] = Message.de_json(data.get('message'))
+        data['from_user'] = User.de_json(data.get('from'), bot)
+        data['message'] = Message.de_json(data.get('message'), bot)
 
-        return CallbackQuery(**data)
+        return CallbackQuery(bot=bot, **data)
 
     def to_dict(self):
         """
@@ -54,3 +65,7 @@ class CallbackQuery(TelegramObject):
         # Required
         data['from'] = data.pop('from_user', None)
         return data
+
+    def answer(self, *args, **kwargs):
+        """Shortcut for ``bot.answerCallbackQuery(update.callback_query.id, *args, **kwargs)``"""
+        return self.bot.answerCallbackQuery(self.id, *args, **kwargs)
