@@ -43,10 +43,11 @@ class ForceReply(ReplyMarkup):
         self.selective = bool(kwargs.get('selective', False))
 
     @staticmethod
-    def de_json(data):
+    def de_json(data, bot):
         """
         Args:
-            data (str):
+            data (dict):
+            bot (telegram.Bot):
 
         Returns:
             telegram.ForceReply:
