@@ -16,18 +16,17 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """This module contains a object that represents a Telegram
 ReplyKeyboardMarkup."""
 
-from telegram import ReplyMarkup
+from telegram import ReplyMarkup, KeyboardButton
 
 
 class ReplyKeyboardMarkup(ReplyMarkup):
     """This object represents a Telegram ReplyKeyboardMarkup.
 
     Attributes:
-        keyboard (List[List[str]]):
+        keyboard (List[List[:class:`telegram.KeyboardButton`]]):
         resize_keyboard (bool):
         one_time_keyboard (bool):
         selective (bool):
@@ -42,9 +41,7 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         selective (Optional[bool]):
     """
 
-    def __init__(self,
-                 keyboard,
-                 **kwargs):
+    def __init__(self, keyboard, **kwargs):
         # Required
         self.keyboard = keyboard
         # Optionals
@@ -53,10 +50,11 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         self.selective = bool(kwargs.get('selective', False))
 
     @staticmethod
-    def de_json(data):
+    def de_json(data, bot):
         """
         Args:
-            data (str):
+            data (dict):
+            bot (telegram.Bot):
 
         Returns:
             telegram.ReplyKeyboardMarkup:
@@ -64,4 +62,20 @@ class ReplyKeyboardMarkup(ReplyMarkup):
         if not data:
             return None
 
+        data['keyboard'] = [KeyboardButton.de_list(keyboard, bot) for keyboard in data['keyboard']]
+
         return ReplyKeyboardMarkup(**data)
+
+    def to_dict(self):
+        data = super(ReplyKeyboardMarkup, self).to_dict()
+
+        data['keyboard'] = []
+        for row in self.keyboard:
+            r = []
+            for button in row:
+                if hasattr(button, 'to_dict'):
+                    r.append(button.to_dict())  # telegram.KeyboardButton
+                else:
+                    r.append(button)  # str
+            data['keyboard'].append(r)
+        return data
