@@ -16,7 +16,6 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """This module contains a object that represents a Telegram Sticker."""
 
 from telegram import PhotoSize, TelegramObject
@@ -30,6 +29,7 @@ class Sticker(TelegramObject):
         width (int):
         height (int):
         thumb (:class:`telegram.PhotoSize`):
+        emoji (str):
         file_size (int):
 
     Args:
@@ -40,27 +40,26 @@ class Sticker(TelegramObject):
 
     Keyword Args:
         thumb (Optional[:class:`telegram.PhotoSize`]):
+        emoji (Optional[str]):
         file_size (Optional[int]):
     """
 
-    def __init__(self,
-                 file_id,
-                 width,
-                 height,
-                 **kwargs):
+    def __init__(self, file_id, width, height, **kwargs):
         # Required
         self.file_id = str(file_id)
         self.width = int(width)
         self.height = int(height)
         # Optionals
         self.thumb = kwargs.get('thumb')
+        self.emoji = kwargs.get('emoji', '')
         self.file_size = int(kwargs.get('file_size', 0))
 
     @staticmethod
-    def de_json(data):
+    def de_json(data, bot):
         """
         Args:
-            data (str):
+            data (dict):
+            bot (telegram.Bot):
 
         Returns:
             telegram.Sticker:
@@ -68,6 +67,6 @@ class Sticker(TelegramObject):
         if not data:
             return None
 
-        data['thumb'] = PhotoSize.de_json(data.get('thumb'))
+        data['thumb'] = PhotoSize.de_json(data.get('thumb'), bot)
 
         return Sticker(**data)
